=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2006-04-08 19:00:33 +0000
+++ bzrlib/merge.py	2006-04-08 21:22:36 +0000
@@ -789,8 +789,8 @@
         this_revision_id = self.this_revision_tree.inventory[file_id].revision
         other_revision_id = \
             self.other_revision_tree.inventory[file_id].revision
-        plan =  weave.plan_merge(this_revision_id, other_revision_id)
-        wm = WeaveMerge(plan, '<<<<<<< TREE\n', '>>>>>>> MERGE-SOURCE\n')
+        wm = WeaveMerge(weave, this_revision_id, other_revision_id, 
+                        '<<<<<<< TREE\n', '>>>>>>> MERGE-SOURCE\n')
         return wm.merge_lines(self.reprocess)
 
     def text_merge(self, file_id, trans_id):

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2006-04-08 16:58:12 +0000
+++ bzrlib/versionedfile.py	2006-04-08 21:22:36 +0000
@@ -394,7 +394,19 @@
         """Walk the names list."""
         return iter(self.versions())
 
-    def plan_merge(self, ver_a, ver_b):
+    def plan_merge(versionedfile, ver_a, ver_b):
+        return PlanWeaveMerge.plan_merge(versionedfile, ver_a, ver_b)
+
+    def weave_merge(self, plan, a_marker='<<<<<<< \n', b_marker='>>>>>>> \n'):
+        return PlanWeaveMerge(plan, a_marker, b_marker).merge_lines()
+
+class PlanWeaveMerge(TextMerge):
+    def __init__(self, plan, a_marker='<<<<<<< \n', b_marker='>>>>>>> \n'):
+        TextMerge.__init__(self, a_marker, b_marker)
+        self.plan = plan
+
+    @staticmethod
+    def plan_merge(versionedfile, ver_a, ver_b):
         """Return pseudo-annotation indicating how the two versions merge.
 
         This is computed between versions a and b and their common
@@ -402,11 +414,12 @@
 
         Weave lines present in none of them are skipped entirely.
         """
-        inc_a = set(self.get_ancestry([ver_a]))
-        inc_b = set(self.get_ancestry([ver_b]))
+        inc_a = set(versionedfile.get_ancestry([ver_a]))
+        inc_b = set(versionedfile.get_ancestry([ver_b]))
         inc_c = inc_a & inc_b
 
-        for lineno, insert, deleteset, line in self.walk([ver_a, ver_b]):
+        for lineno, insert, deleteset, line in\
+            versionedfile.walk([ver_a, ver_b]):
             if deleteset & inc_c:
                 # killed in parent; can't be in either a or b
                 # not relevant to our work
@@ -440,14 +453,6 @@
 
         yield 'unchanged', ''           # terminator
 
-    def weave_merge(self, plan, a_marker='<<<<<<< \n', b_marker='>>>>>>> \n'):
-        return WeaveMerge(plan, a_marker, b_marker).merge_lines()
-
-class WeaveMerge(TextMerge):
-    def __init__(self, plan, a_marker='<<<<<<< \n', b_marker='>>>>>>> \n'):
-        TextMerge.__init__(self, a_marker, b_marker)
-        self.plan = plan
-
     def _merge_struct(self):
         lines_a = []
         lines_b = []
@@ -497,6 +502,13 @@
                                  'killed-base', 'killed-both'), state
 
 
+class WeaveMerge(PlanWeaveMerge):
+    def __init__(self, versionedfile, ver_a, ver_b, 
+        a_marker='<<<<<<< \n', b_marker='>>>>>>> \n'):
+        plan = self.plan_merge(versionedfile, ver_a, ver_b)
+        PlanWeaveMerge.__init__(self, plan, a_marker, b_marker)
+
+
 class InterVersionedFile(InterObject):
     """This class represents operations taking place between two versionedfiles..
 

